#
# spec file for package velero
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           velero
Version:        1.16.1
Release:        1.1
Summary:        Backup program with deduplication and encryption
License:        Apache-2.0
Group:          Productivity/Archiving/Backup
URL:            https://velero.io
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
velero is a backup program. It supports verification, encryption,
snapshots and deduplication.

%package velero-restic-restore-helper
Summary:        Restic restore helper for %{name}
Group:          Productivity/Archiving/Backup
Requires:       %{name} = %{version}
Supplements:    packageand(velero:velero-restic-restore-helper)

%description velero-restic-restore-helper
Restic restore helper for %{name}.

%package bash-completion
Summary:        Bash Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%setup -q -a1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

go build \
   -installsuffix "static" \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/vmware-tanzu/%{name}/pkg/buildinfo.Version=v%{version} \
   -X github.com/vmware-tanzu/%{name}/pkg/buildinfo.GitSHA=${COMMIT_HASH} \
   -X github.com/vmware-tanzu/%{name}/pkg/buildinfo.GitTreeState=clean" \
   -o bin/%{name} ./cmd/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%files fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%changelog
* Mon May 19 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.16.1:
  * Call WaitGroup.Done() once only when PVB changes to final
    status the first time to avoid panic
  * Support using image registry proxy in more cases.
  * Add default bakcup repository configuration for E2E.
  * Add VolumeSnapshotContent into the RIA and the mustHave
    resource list. (#8926)
  * bump up base image
  * Remove pushing images to GCR.
  * For not found errors on managed fields, add restore warning
  * issue-8878: relief node os deduction error checks
  * Bump Golang and golang.org/x/net to fix CVEs.
* Mon Apr 14 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 1.16.0:
  * Highlights
  - Windows cluster support
    In v1.16, Velero supports to run in Windows clusters and
    backup/restore Windows workloads, either stateful or
    stateless:
  - Hybrid build and all-in-one image: the build process is
    enhanced to build an all-in-one image for hybrid CPU
    architecture and hybrid platform. For more information,
    check the design
    https://github.com/vmware-tanzu/velero/blob/main/design/multiple-arch-build-with-windows.md
  - Deployment in Windows clusters: Velero node-agent, data
    mover pods and maintenance jobs now support to run in both
    linux and Windows nodes
  - Data mover backup/restore Windows workloads: Velero
    built-in data mover supports Windows workloads throughout
    its full cycle, i.e., discovery, backup, restore, pre/post
    hook, etc. It automatically identifies Windows workloads
    and schedules data mover pods to the right group of nodes
    Check the epic issue #8289 for more information.
  - Parallel Item Block backup
    v1.16 now supports to back up item blocks in parallel.
    Specifically, during backup, correlated resources are grouped
    in item blocks and Velero backup engine creates a thread pool
    to back up the item blocks in parallel. This significantly
    improves the backup throughput, especially when there are
    large scale of resources.
    Pre/post hooks also belongs to item blocks, so will also run
    in parallel along with the item blocks.
    Users are allowed to configure the parallelism through the
  - -item-block-worker-count Velero server parameter. If not
    configured, the default parallelism is 1.
    For more information, check issue #8334.
  - Data mover restore enhancement in scalability
    In previous releases, for each volume of WaitForFirstConsumer
    mode, data mover restore is only allowed to happen in the
    node that the volume is attached. This severely degrades the
    parallelism and the balance of node resource(CPU, memory,
    network bandwidth) consumption for data mover restore
    (#8044).
    In v1.16, users are allowed to configure data mover restores
    running and spreading evenly across all nodes in the cluster.
    The configuration is done through a new flag
    ignoreDelayBinding in node-agent configuration (#8242).
  - Data mover enhancements in observability
    In 1.16, some observability enhancements are added:
  - Output various statuses of intermediate objects for
    failures of data mover backup/restore (#8267)
  - Output the errors when Velero fails to delete intermediate
    objects during clean up (#8125)
    The outputs are in the same node-agent log and enabled
    automatically.
  - CSI snapshot backup/restore enhancement in usability
    In previous releases, a unnecessary VolumeSnapshotContent
    object is retained for each backup and synced to other
    clusters sharing the same backup storage location. And during
    restore, the retained VolumeSnapshotContent is also restored
    unnecessarily.
    In 1.16, the retained VolumeSnapshotContent is removed from
    the backup, so no unnecessary CSI objects are synced or
    restored.
    For more information, check issue #8725.
  - Backup Repository Maintenance enhancement in resiliency and
    observability
    In v1.16, some enhancements of backup repository maintenance
    are added to improve the observability and resiliency:
  - A new backup repository maintenance history section, called
    RecentMaintenance, is added to the BackupRepository CR.
    Specifically, for each BackupRepository, including
    start/completion time, completion status and error message.
    (#7810)
  - Running maintenance jobs are now recaptured after Velero
    server restarts. (#7753)
  - The maintenance job will not be launched for readOnly
    BackupStorageLocation. (#8238)
  - The backup repository will not try to initialize a new
    repository for readOnly BackupStorageLocation. (#8091)
  - Users now are allowed to configure the intervals of an
    effective maintenance in the way of normalGC, fastGC and
    eagerGC, through the fullMaintenanceInterval parameter in
    backupRepository configuration. (#8364)
  - Volume Policy enhancement of filtering volumes by PVC labels
    In v1.16, Volume Policy is extended to support filtering
    volumes by PVC labels. (#8256).
  - Resource Status restore per object
    In v1.16, users are allowed to define whether to restore
    resource status per object through an annotation
    velero.io/restore-status set on the object. (#8204).
  - Velero Restore Helper binary is merged into Velero image
    In v1.16, Velero banaries, i.e., velero, velero-helper and
    velero-restore-helper, are all included into the single
    Velero image. (#8484).
  - Limitations/Known issues
  - Limitations of Windows support
  - fs-backup is not supported for Windows workloads and so
    fs-backup runs only in linux nodes for linux workloads
  - Backup/restore of NTFS extended attributes/advanced
    features are not supported, i.e., Security Descriptors,
    System/Hidden/ReadOnly attributes, Creation Time, NTFS
    Streams, etc.
  * All Changes
    Please check the release notes for a list of all changes:
    https://github.com/vmware-tanzu/velero/releases/tag/v1.16.0
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.15.2:
  * 1.15.2 change-log
  * Check the PVB status via podvolume Backupper rather than
    calling API server to avoid API server issue
  * 1.15.2 change-log
  * Don't include excluded items in ItemBlocks
  * 1.15.2 changelog
  * fix(pkg/repository/maintenance): don't panic when there's no
    container statuses
  * Use the SC mapping cm in all migration cases.
* Fri Dec 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.15.1:
  * Skip the deprecation message for the dry-run install CLI JSON
  * output.
  * Bug fix: increase the WaitGroup counter before start the
  * goroutine
  * Pin the version of Golang and base image for v1.15.1
  * Modify the Init logic to fix the migration case error.
  * hide restic deprecation warning for install with crd-only
  * Refactor the migration cases.
  * Modify the schedule cases.
  * Modify the StorageClass install and delete code.
  * 1.15.1 change-log
  * Modify upgrade and migration cases.
  * Modify other cases to support VKS environment.
  * E2E supports VKS data mover environment.
  * Make change to support VKS environment.
  * Bump the golang.org/x/crypto for Restic to fix CVE-2024-45337.
  * Bump the golang.org/x/net for Velero and Restic to fix
  * CVE-2024-45338.
  * Bump golang.org/x/crypto to v0.31.0 to fix CVEs.
  * Fix backup post hook issue
  * add diagnostic for data mover exposer
  * add diagnostic for data mover exposer
  * add diagnostic for data mover exposer
  * Set hinting region to use for GetBucketRegion() in
  * pkg/repository/config/aws.go
  * check existence of the same label from node-agent
  * issue 8433: add ask label to data mover pods
  * fix prepare timeout issue
  * Add SecurityContext to restore-helper
  * Reduces go.mod minimum go to patch 1.22.0
  * Add nil check for updating DataUpload VolumeInfo in finalizing
  * phase.
  * issue 8391: check ErrCancelled from suffix
  * issue 8394: move closeDataPath outside callbacks
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.15.0:
  Changelog: https://velero.io/docs/v1.15/
  Upgrading: https://velero.io/docs/v1.15/upgrade-to-1.15/
  * Data mover micro service
    Data transfer activities for CSI Snapshot Data Movement are
    moved from node-agent pods to dedicate backupPods or
    restorePods. This brings many benefits such as:
  - This avoids to access volume data through host path, while
    host path access is privileged and may involve security
    escalations, which are concerned by users.
  - This enables users to to control resource (i.e., cpu, memory)
    allocations in a granular manner, e.g., control them per
    backup/restore of a volume.
  - This enhances the resilience, crash of one data movement
    activity won't affect others.
  - This prevents unnecessary full backup because of host path
    changes after workload pods restart.
  - For more information, check the design
    https://github.com/vmware-tanzu/velero/blob/main/design/Implemented/vgdp-micro-service/vgdp-micro-service.md.
  * Item Block concepts and ItemBlockAction (IBA) plugin
    Item Block concepts are introduced for resource backups to help
    to achieve multiple thread backups. Specifically, correlated
    resources are categorized in the same item block and item
    blocks could be processed concurrently in multiple threads.
    ItemBlockAction plugin is introduced to help Velero to
    categorize resources into item blocks. At present, Velero
    provides built-in IBAs for pods and PVCs and Velero also
    supports customized IBAs for any resources.
    In v1.15, Velero doesn't support multiple thread process of
    item blocks though item block concepts and IBA plugins are
    fully supported. The multiple thread support will be delivered
    in future releases.
    For more information, check the design
    https://github.com/vmware-tanzu/velero/blob/main/design/backup-performance-improvements.md.
  * Node selection for repository maintenance job
    Repository maintenance are resource consuming tasks, Velero now
    allows you to configure the nodes to run repository maintenance
    jobs, so that you can run repository maintenance jobs in idle
    nodes or avoid them to run in nodes hosting critical workloads.
    To support the configuration, a new repository maintenance
    configuration configMap is introduced.
    For more information, check the document
    https://velero.io/docs/v1.15/repository-maintenance/.
  * Backup PVC read-only configuration
    In 1.15, Velero allows you to configure the data mover
    backupPods to read-only mount the backupPVCs. In this way, the
    data mover expose process could be significantly accelerated
    for some storages (i.e., ceph).
    To support the configuration, a new backup PVC configuration
    configMap is introduced.
    For more information, check the document
    https://velero.io/docs/v1.15/data-movement-backup-pvc-configuration/.
  * Backup PVC storage class configuration
    In 1.15, Velero allows you to configure the storageclass used
    by the data mover backupPods. In this way, the provision of
    backupPVCs don't need to adhere to the same pattern as workload
    PVCs, e.g., for a backupPVC, it only needs one replica,
    whereas, the a workload PVC may have multiple replicas.
    To support the configuration, the same backup PVC configuration
    configMap is used.
    For more information, check the document
    https://velero.io/docs/v1.15/data-movement-backup-pvc-configuration/.
  * Backup repository data cache configuration
    The backup repository may need to cache data on the client side
    during various repository operations, i.e., read, write,
    maintenance, etc. The cache consumes the root file system space
    of the pod where the repository access happens.
    In 1.15, Velero allows you to configure the total size of the
    cache per repository. In this way, if your pod doesn't have
    enough space in its root file system, the pod won't be evicted
    due to running out of ephemeral storage.
    To support the configuration, a new backup repository
    configuration configMap is introduced.
    For more information, check the document
    https://velero.io/docs/v1.15/backup-repository-configuration/.
  * Performance improvements
    In 1.15, several performance related issues/enhancements are
    included, which makes significant performance improvements in
    specific scenarios:
  - There was a memory leak of Velero server after plugin calls,
    now it is fixed, see issue #7925
  - The client-burst/client-qps parameters are automatically
    inherited to plugins, so that you can use the same velero
    server parameters to accelerate the plugin executions when
    large number of API server calls happen, see issue #7806
  - Maintenance of Kopia repository takes huge memory in
    scenarios that huge number of files have been backed up,
    Velero 1.15 has included the Kopia upstream enhancement to
    fix the problem, see issue #7510
* Fri Sep 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.14.1:
  * change log for 1.14.1
  * Bump base image and golang version to fix CVEs.
  * Add changelog file.
  * Avoid wrapping failed PVB status with empty message.
  * Expose PVPatchMaximumDuration timeout for custom configuration
  * update changelog filename
  * fix linter check error (#8014)
  * Reuse existing plugin manager for get/put volume info
  * Skip PV patch step in Restoe workflow for WaitForFirstConsumer
    VolumeBindingMode Pending state PVCs (#7953)
  * Reset VolumeSnapshotRef in Backup Sync Flow (#8004)
  * Check whether the namespaces specified in namespace filter
    exist.
  * Check whether the volume's source is PVC before fetching its
    PV.
  * Expose the VolumeHelper to third-party plugins.
  * issue 7904:and limitation clarification for change PVC
    selected-node feature
  * Don't consider unschedulable pods unrecoverable
* Fri Jul 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- fix version output: use actual hash and prefix version with a 'v'
  This fixes the following warning:
  `# WARNING: the client version does not match the server version.
  Please update client`
- change to using obs_scm to have velero.obsinfo which contains the
  commit hash required by the ldflags
* Mon Jun 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.14.0:
  * Highlights
  - The maintenance work for kopia/restic backup repositories is
    run in jobs
    Since velero started using kopia as the approach for
    filesystem-level backup/restore, we've noticed an issue when
    velero connects to the kopia backup repositories and performs
    maintenance, it sometimes consumes excessive memory that can
    cause the velero pod to get OOM Killed. To mitigate this
    issue, the maintenance work will be moved out of velero pod
    to a separate kubernetes job, and the user will be able to
    specify the resource request in "velero install".
  - Volume Policies are extended to support more actions to
    handle volumes
    In an earlier release, a flexible volume policy was
    introduced to skip certain volumes from a backup. In v1.14
    we've made enhancement to this policy to allow the user to
    set how the volumes should be backed up. The user will be
    able to set "fs-backup" or "snapshot" as value of “action" in
    the policy and velero will backup the volumes accordingly.
    This enhancement allows the user to achieve a fine-grained
    control like "opt-in/out" without having to update the target
    workload. For more details please refer to
    https://velero.io/docs/v1.14/resource-filtering/#supported-volumepolicy-actions
  - Node Selection for Data Movement Backup
    In velero the data movement flow relies on datamover pods,
    and these pods may take substantial resources and keep
    running for a long time. In v1.14, the user will be able to
    create a configmap to define the eligible nodes on which the
    datamover pods are launched. For more details refer to
    https://velero.io/docs/v1.14/data-movement-backup-node-selection/
  - VolumeInfo metadata for restored volumes
    In v1.13, we introduced volumeinfo metadata for backup to
    help velero CLI and downstream adopter understand how velero
    handles each volume during backup. In v1.14, similar metadata
    will be persisted for each restore. velero CLI is also
    updated to bring more info in the output of "velero restore
    describe".
  - "Finalizing" phase is introduced to restores
    The "Finalizing" phase is added to the state transition flow
    to restore, which helps us fix several issues: The labels
    added to PVs will be restored after the data in the PV is
    restored via volumesnapshotter. The post restore hook will be
    executed after datamovement is finished.
  - Certificate-based authentication support for Azure
    Besides the service principal with secret(password)-based
    authentication, Velero introduces the new support for service
    principal with certificate-based authentication in v1.14.0.
    This approach enables you to adopt a phishing resistant
    authentication by using conditional access policies, which
    better protects Azure resources and is the recommended way by
    Azure.
  * Runtime and dependencies
  - Golang runtime: v1.22.2
  - kopia: v0.17.0
  * Limitations/Known issues
  - For the external BackupItemAction plugins that take snapshots
    for PVs, such as vsphere plugin. If the plugin checks the
    value of the field "snapshotVolumes" in the backup spec as a
    criteria for snapshot, the settings in the volume policy will
    not take effect. For example, if the "snapshotVolumes" is set
    to False in the backup spec, but a volume meets the condition
    in the volume policy for "snapshot" action, because the
    plugin will not check the settings in the volume policy, the
    plugin will not take snapshot for the volume. For more
    details please refer to #7818
  * Breaking changes
  - CSI plugin has been merged into velero repo in v1.14 release.
    It will be installed by default as an internal plugin, and
    should not be installed via "–plugins " parameter in "velero
    install" command.
  - The default resource requests and limitations for node agent
    are removed in v1.14, to make the node agent pods have the
    QoS class of "BestEffort", more details please refer to #7391
  - There's a change in namespace filtering behavior during
    backup: In v1.14, when the
    includedNamespaces/excludedNamespaces fields are not set and
    the labelSelector/OrLabelSelectors are set in the backup
    spec, the backup will only include the namespaces which
    contain the resources that match the label selectors, while
    in previous releases all namespaces will be included in the
    backup with such settings. More details refer to #7105
  - Patching the PV in the "Finalizing" state may cause the
    restore to be in "PartiallyFailed" state when the PV is
    blocked in "Pending" state, while in the previous release the
    restore may end up being in "Complete" state. For more
    details refer to #7866
  * All Changes
  - Fix backup log to show error string, not index (#7805,
    @piny940)
  - Modify the volume helper logic. (#7794, @blackpiglet)
  - Add documentation for extension of volume policy feature
    (#7779, @shubham-pampattiwar)
  - Surface errors when waiting for backupRepository and timeout
    occurs (#7762, @kaovilai)
  - Add existingResourcePolicy restore CR validation to
    controller (#7757, @kaovilai)
  - Fix condition matching in resource modifier when there are
    multiple rules (#7715, @27149chen)
  - Bump up the version of KinD and k8s in github actions (#7702,
    @reasonerjt)
  - Implementation for Extending VolumePolicies to support more
    actions (#7664, @shubham-pampattiwar)
  - Migrate from github.com/Azure/azure-storage-blob-go to
    github.com/Azure/azure-sdk-for-go/sdk/storage/azblob (#7598,
    @mmorel-35)
  - When Included/ExcludedNamespaces are omitted, and
    LabelSelector or OrLabelSelector is used, namespaces without
    selected items are excluded from backup. (#7697,
    @blackpiglet)
  - Display CSI snapshot restores in restore describe (#7687,
    @reasonerjt)
  - Use specific credential rather than the credential chain for
    Azure (#7680, @ywk253100)
  - Modify hook docs for clarity on displaying hook execution
    results (#7679, @allenxu404)
  - Wait for results of restore exec hook executions in
    Finalizing phase instead of InProgress phase (#7619,
    @allenxu404)
  - migrating to sdk/resourcemanager/**/arm** from
    services/**/mgmt/** (#7596, @mmorel-35)
  - Bump up to go1.22 (#7666, @reasonerjt)
  - Fix issue #7648. Adjust the exposing logic to avoid exposing
    failure and snapshot leak when expose fails (#7662,
    @Lyndon-Li)
  - Track and persist restore volume info (#7630, @reasonerjt)
  - Check the existence of the namespaces provided in the
    "--include-namespaces" option (#7569, @ywk253100)
  - Add the finalization phase to the restore workflow (#7377,
    @allenxu404)
  - Upgrade the version of go plugin related libs/tools (#7373,
    @ywk253100)
  - Check resource Group Version and Kind is available in cluster
    before attempting restore to prevent being stuck. (#7322,
    @kaovilai)
  - Merge CSI plugin code into Velero. (#7609, @blackpiglet)
  - Fix issue #7391, remove the default constraint for node-agent
    pods (#7488, @Lyndon-Li)
  - Fix DataDownload fails during restore for empty PVC workload
    (#7521, @qiuming-best)
  - Add repository maintenance job (#7451, @qiuming-best)
  - Check whether the VolumeSnapshot's source PVC is nil before
    using it.
  - Skip populate VolumeInfo for data-moved PV when CSI is not
    enabled. (#7515, @blackpiglet)
  - Fix issue #7308, change the data path requeue time to 5
    second for data mover backup/restore, PVB and PVR. (#7458,
    @Lyndon-Li)
  - Patch newly dynamically provisioned PV with volume info to
    restore custom setting of PV (#7504, @allenxu404)
  - Adjust the logic for the backup_last_status metrics to stop
    incorrectly incrementing over time (#7445, @allenxu404)
  - dependabot: support github-actions updates (#7594,
    @mmorel-35)
  - Include the design for adding the finalization phase to the
    restore workflow (#7317, @allenxu404)
  - Fix issue #7211. Enable advanced feature capability and add
    support to concatenate objects for unified repo. (#7452,
    @Lyndon-Li)
  - Add design to introduce restore volume info (#7610,
    @reasonerjt)
  - Increase the k8s client QPS/burst to avoid throttling request
    errors (#7311, @ywk253100)
  - Support update the backup VolumeInfos by the Async ops
    result. (#7554, @blackpiglet)
  - FS backup create PodVolumeBackup when the backup excluded
    PVC,
  - so I added logic to skip PVC volume type when PVC is not
    included in the backup resources to be backed up. (#7472,
    @sbahar619)
  - Respect and use credentialsFile specified in BSL.spec.config
    when IRSA is configured over Velero Pod Environment
    credentials (#7374, @reasonerjt)
  - Move the native snapshot definition code into internal
    directory (#7544, @blackpiglet)
  - Fix issue #7036. Add the implementation of node selection for
    data mover backups (#7437, @Lyndon-Li)
  - Fix issue #7535, add the MustHave resource check during item
    collection and item filter for restore (#7585, @Lyndon-Li)
  - build(deps): bump json-patch to v5.8.0 (#7584, @mmorel-35)
  - Add confirm flag to velero plugin add (#7566, @kaovilai)
  - do not skip unknown gvr at the beginning and get new gr when
    kind is changed (#7523, @27149chen)
  - Fix snapshot leak for backup (#7558, @qiuming-best)
  - For issue #7036, add the document for data mover node
    selection (#7640, @Lyndon-Li)
  - Add design for Extending VolumePolicies to support more
    actions (#6956, @shubham-pampattiwar)
  - BackupRepositories associated with a BSL are invalidated when
    BSL is (re-)created. (#7380, @kaovilai)
  - Improve the concurrency for PVBs in different pods (#7571,
    @ywk253100)
  - Bump up Kopia to v0.16.0 and open kopia repo with no index
    change (#7559, @Lyndon-Li)
  - Bump up the versions of several Kubernetes-related libs
    (#7489, @ywk253100)
  - Make parallel restore configurable (#7512, @qiuming-best)
  - Support certificate-based authentication for Azure (#7549,
    @ywk253100)
  - Fix issue #7281, batch delete snapshots in the same repo
    (#7438, @Lyndon-Li)
  - Add CRD name to error message when it is not ready to...
* Wed Apr 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.13.2:
  * Add changelog for v1.13.2
  * Bump Golang version, and bump protobuf version.
  * Empty the list before next round of listing
  * Upgrade codecov action to v4
  * issue 7535: don't exclude resources in MustHave list during
    restore
  * Bump up the versions of severel Kubernetes-related libs
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.13.1:
  * Generate the changelog for release 1.13.1
  * Modify the label used by the restore CLI to filter the PVR.
  * Adjust the logic for the backup_last_status metrics to stop
    incorrectly incrementing over time
  * bump up upgrade path to 1.13
  * issue 7308: change the data path requeue time to 5 second
  * Don't return error when no credential file found
  * Fix the `velero repo get` nil pointer issue.
  * BackupRepositories associated with a BSL are invalidated when
    BSL is (re-)created. (#7380)
  * Add `ParallelFilesUpload` for schedule creation.
  * Fix server start failure when no default BSL
* Mon Jan 29 2024 opensuse_buildservice@ojkastl.de
- BuildRequire go1.21
- Update to version 1.13.0:
  * Upgrading
    https://velero.io/docs/v1.13/upgrade-to-1.13/
  * Resource Modifier Enhancement
  - Velero introduced the Resource Modifiers in v1.12.0. This
    feature allows users to specify a ConfigMap with a set of
    rules to modify the resources during restoration. However,
    only the JSON Patch is supported when creating the rules, and
    JSON Patch has some limitations, which cannot cover all use
    cases. In v1.13.0, Velero adds new support for JSON Merge
    Patch and Strategic Merge Patch, which provide more power and
    flexibility and allow users to use the same ConfigMap to
    apply patches on the resources. More design details can be
    found in Support JSON Merge Patch and Strategic Merge Patch
    in Resource Modifiers design. For instructions on how to use
    the feature, please refer to the Resource Modifiers doc.
  * Node-Agent Concurrency
  - Velero data movement activities from fs-backups and CSI
    snapshot data movements run in Velero node-agent, so may be
    hosted by every node in the cluster and consume resources
    (i.e. CPU, memory, network bandwidth) from there. With v1.13,
    users are allowed to configure how many data movement
    activities (a.k.a, loads) run in each node globally or by
    node, so that users can better leverage the performance of
    Velero data movement activities and the resource consumption
    in the cluster. For more information, check the Node-Agent
    Concurrency document.
  * Parallel Files Upload Options
  - Velero now supports configurable options for parallel files
    upload when using Kopia uploader to do fs-backups or CSI
    snapshot data movements which makes speed up backup possible.
  * Write Sparse Files Options
  - If using fs-restore or CSI snapshot data movements, it’s
    supported to write sparse files during restore. For more
    information, please check Here.
  * Backup Describe
  - In v1.13, the Backup Volume section is added to the velero
    backup describe command output. The backup Volumes section
    describes information for all the volumes included in the
    backup of various backup types, i.e. native snapshot,
    fs-backup, CSI snapshot, and CSI snapshot data movement.
    Particularly, the velero backup description now supports
    showing the information of CSI snapshot data movements, which
    is not supported in v1.12.
    Additionally, backup describe command will not check
    EnableCSI feature gate from client side, so if a backup has
    volumes with CSI snapshot or CSI snapshot data movement,
    backup describe command always shows the corresponding
    information in its output.
  * Backup's new VolumeInfo metadata
  - Create a new metadata file in the backup repository's backup
    name sub-directory to store the backup-including PVC and PV
    information. The information includes the backing-up method
    of the PVC and PV data, snapshot information, and status. The
    VolumeInfo metadata file determines how the PV resource
    should be restored. The Velero downstream software can also
    use this metadata file to get a summary of the backup's
    volume data information.
  * Enhancement for CSI Snapshot Data Movements when Velero Pod
    Restart
  - When performing backup and restore operations, enhancements
    have been implemented for Velero server pods or node agents
    to ensure that the current backup or restore process is not
    stuck or interrupted after restart due to certain exceptional
    circumstances.
  * New status fields added to show hook execution details
  - Hook execution status is now included in the backup/restore
    CR status and displayed in the backup/restore describe
    command output. Specifically, it will show the number of
    hooks which attempted to execute under the HooksAttempted
    field and the number of hooks which failed to execute under
    the HooksFailed field.
  * AWS SDK Bump Up
  - Bump up AWS SDK for Go to version 2, which offers significant
    performance improvements in CPU and memory utilization over
    version 1.
  * Azure AD/Workload Identity Support
  - Azure AD/Workload Identity is the recommended approach to do
    the authentication with Azure services/AKS, Velero has
    introduced support for Azure AD/Workload Identity on the
    Velero Azure plugin side in previous releases, and in v1.13.0
    Velero adds new support for Kopia operations(file system
    backup/data mover/etc.) with Azure AD/Workload Identity.
  * Runtime and dependencies
    To fix CVEs and keep pace with Golang, Velero made changes as
    follows:
  - Bump Golang runtime to v1.21.6.
  - Bump several dependent libraries to new versions.
  - Bump Kopia to v0.15.0.
  * Breaking changes
  - Backup describe command: due to the backup describe output
    enhancement, some existing information (i.e. the output for
    native snapshot, CSI snapshot, and fs-backup) has been moved
    to the Backup Volumes section with some format changes.
  - API type changes: changes the field DataMoverConfig in
    DataUploadSpec from `*map[string][string]` to
    map[string]string`
  - Velero install command: due to the issue #7264, v1.13.0
    introduces a break change that make the informer cache
    enabled by default to keep the actual behavior consistent
    with the helper message(the informer cache is disabled by
    default before the change).
  * Limitations/Known issues
  - The backup's VolumeInfo metadata doesn't have the information
    updated in the async operations. This function could be
    supported in v1.14 release.
  * Note
  - Velero introduces the informer cache which is enabled by
    default. The informer cache improves the restore performance
    but may cause higher memory consumption. Increase the memory
    limit of the Velero pod or disable the informer cache by
    specifying the --disable-informer-cache option when
    installing Velero if you get the OOM error.
  * Deprecation announcement
  - The generated k8s clients, informers, and listers are
    deprecated in the Velero v1.13 release. They are put in the
    Velero repository's pkg/generated directory. According to the
    n+2 supporting policy, the deprecated are kept for two more
    releases. The pkg/generated directory should be deleted in
    the v1.15 release.
  - After the backup VolumeInfo metadata file is added to the
    backup, Velero decides how to restore the PV resource
    according to the VolumeInfo content. To support the backup
    generated by the older version of Velero, the old logic is
    also kept. The support for the backup without the VolumeInfo
    metadata file will be kept for two releases. The support
    logic will be deleted in the v1.15 release.
* Mon Jan 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.12.3:
  * Modify changelog for v1.12.3
  * Add v1.12.3 changelog
  * isue 6928: remove snapshot deletion timeout for PVB
  * Fix intermediate pv delete for data mover
  * Node agent restart enhancement
  * Don't fail backup/restore on velero server restart in
    PhaseWaitingForPluginOperation
  * Issue 7244: delete incomplete snapshot automatically for kopia
    uploader
    uploader
  * Fix issue #7163.
  * issue 7189: generic restore - don't assume the first volume as
    the restore volume
* Mon Nov 27 2023 kastl@b1-systems.de
- Update to version 1.12.2:
  * RM support for Escaped bool, float, null (#7118) (#7131)
  * Add v1.12.2 changelog
  * revert test changes
  * `make update`
  * update changelog to reflect removed waits
  * CSIFeatureFlag enable check
  * remove waiting during finalize
  * skip this if SnapshotMoveData
  * refactor backup snapshot status updates into
    UpdateBackupSnapshotsStatus() and run in
    backup_finalizer_controller
  * Add PatchResource unit test for backup status
  * Issue 7068: add a finalizer to protect retained VSC
  * Bump up Velero base image to latest patch release
  * update changelog
  * Merge pull request #6917 from 27149chen/rm-improvement
  * Fix node-agent missing metrics-addr parms to define the server
    start.
  * issue 7094: fallback to full backup if previous snapshot is not
    found
  * Add DataUpload Result and CSI VolumeSnapshot check for restore
    PV.
  * Truncate the credential file to avoid the change of secret
    content messing it up
  * issue 7027: backup exposer -- don't assume first volume as the
    backup volume
  * restore: Use warning when Create IsAlreadyExist and Get error
    (#7004)
  * Read information from the credential specified by BSL
  * Make configmapref check case insensitive (#6804) (#7023)
  * Fix issue 6913
  * CVE-2023-44487 gRPC-Go HTTP/2 Rapid Reset vulnerability
  * Update testbed matrix for v1.12.1
  * kopia/repository/config/aws.go: Set session.Options profile
    from config
* Wed Oct 25 2023 kastl@b1-systems.de
- Update to version 1.12.1:
  * Change v1.12.1 changelog
  * udmrepo use region specified in BSL when s3URL is empty
  * Make Windows build skip BlockMode code.
  * Add v1.12.1 changelog
  * Import auth provider plugins
  * issue #6807: Retry failed create when using generateName
  * Fix CVE-2023-39325.
  * Perf improvements for existing resource restore
  * fix issue 6647
  * Add doc links for new features to release note
  * issue 6734: spread backup pod evenly
  * Replace the base image with paketobuildpacks image
  * [Cherry-pick v1.12]Keep the logs info ns/name is the same with
    other modules.
  * Code clean for backup cmd client. (#6750)
  * Add support for block volumes (#6680) (#6897)
  * Remove legacy label version check, to be added back when
    version is known
  * changelog
  * Handle 1.27 k8s job label changes
  * Fix some wrong logs and code clean.
  * Add go clean in Dockerfile and action. (#6896)
  * code clean for repository (#6768)
  * issue 6880: set ParallelUploadAboveSize as MaxInt64
  * Rename the changelog
  * Add 'orLabelSelector' for backup, restore command
  * issue: move plugin depdending podvolume functions to util pkg
  * issue 6786:always delete VSC regardless of the deletion policy
* Fri Sep 22 2023 kastl@b1-systems.de
- Update to version 1.12.0:
  very big changelog, please find it here:
  https://github.com/vmware-tanzu/velero/releases/tag/v1.12.0
  * Breaking changes
  - Prior to v1.12, the parameter uploader-type for Velero
    installation had a default value of "restic". However,
    starting from this version, the default value has been
    changed to "kopia". This means that Velero will now use Kopia
    as the default path for file system backup.
  - The ways of setting CSI snapshot time have changed in v1.12.
    First, the sync waiting time for creating a snapshot handle
    in the CSI plugin is changed from the fixed 10 minutes into
    backup.Spec.CSISnapshotTimeout. The second, the async waiting
    time for VolumeSnapshot and VolumeSnapshotContent's status
    turning into ReadyToUse in operation uses the operation's
    timeout. The default value is 4 hours.
  - As from Velero helm chart v4.0.0, it supports multiple BSL
    and VSL, and the BSL and VSL have changed from the map into a
    slice, and this breaking change is not backward compatible.
    So it would be best to change the BSL and VSL configuration
    into slices before the Upgrade.
  - Prior to v1.12, deleting the Velero namespace would easily
    remove all the resources within it. However, with the
    introduction of finalizers attached to the Velero CR
    including restore, dataupload, and datadownload in this
    version, directly deleting Velero namespace may get stuck
    indefinitely because the pods responsible for handling the
    finalizers might be deleted before the resources attached to
    the finalizers. To avoid this issue, please use the command
    velero uninstall to delete all the Velero resources or ensure
    that you handle the finalizer appropriately before deleting
    the Velero namespace.
  * Limitations/Known issues
    The Azure plugin supports Azure AD Workload identity way, but
    it only works for Velero native snapshots. It cannot support
    filesystem backup and snapshot data mover scenarios.
  * Upgrading
    https://velero.io/docs/v1.12/upgrade-to-1.12/
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.11.1:
  * Add v1.11.1 changelog. (#6522)
  * Integrate pushing to docker hub and gcr.io in one docker build
    and push command.
  * Fix release-1.11 push github action out of space issue. (#6500)
  * Add support for OpenStack CSI drivers topology keys
  * Bump Golang to v1.20.6 for release-1.11.
  * fix-issue-6297
  * Restore Endpoints before Services (#6316)
  * Fix status.progress not getting updated for backup
  * Make the E2E testing pods obey the restricted pod security
    standard.
  * Fix issue 6182
  * Update Golang to v1.20 for release-1.11 branch. (#6159)
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.11.0:
  very big changelog, please find it here:
  https://github.com/vmware-tanzu/velero/releases/tag/v1.11.0
  * Breaking changes
    The Velero CSI plugin now determines whether to restore
    Volume's data from snapshots on the restore's restorePVs
    setting. Before v1.11, the CSI plugin doesn't check the
    restorePVs parameter setting.
  * Upgrading
    Due to the major changes of file system backup, the old upgrade
    steps are not suitable any more.
    https://velero.io/docs/v1.11/upgrade-to-1.11/
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.10.3:
  * Using gcr.io as velero image registry
  * 1.10.3 change log
  * fix issue 6182
  * Bump v1.10's Golang version to v1.20
  * Ignore not found error during patching managedFields (#6135)
  * fix issue 5972
  * E2E test can read VC credential secret according to vSphere CSI
    driver version.
  * Restore Services before Clusters
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.10.2:
  * fix main CI problem 02
  * fix main CI disk space error
  * Roll back pkg client code for Velero server
  * 1.10.2 change log
  * Update distroless image and fix CVE-2022-41717 for release-1.10
  * Set Kopia IgnoreUnknownTypes in ErrorHandlingPolicy to True for
    ignoring backup unknown file type
  * Add labels for created namespace during velero installation to
    adopt k8s v1.25's PSS and PSA.
  * Restore finalizer and managedFields (#5877)
  * Publish backup results extracted from backup logs
  * Add secret restore item action to handle service account token secret
  * move UpdatePVXStatusToFailed to controller pkg
  * Use updated PVB/PVR for patching Failed Phase during startup
  * Remove container-builder-env section.
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.10.1:
  * Fix Restic v0.14.0 HIGH grade CVEs.
  * add change log
  * bump up golang net
  * add 1.10.1 changelog
  * bump up to golang 1.18.10
  * Add GOARM in Restic builder. Add PR container build action.
  * Remove container-builder-env section.
  * Fix Dockerfile issue.
  * Add Restic builder in Dockerfile.
  * fix issue 5696
  * Fix error with Restic backup empty volumes
  * Fix changelog
  * Prevent nil panic on exec restore hooks (#5675)
  * Fix CVEs scanned by trivy
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.10.0:
  very big changelog, please find it here:
  https://github.com/vmware-tanzu/velero/releases/tag/v1.10.0
  * Upgrading
    Due to the major changes of file system backup, the old upgrade
    steps are not suitable any more.
    https://velero.io/docs/v1.10/upgrade-to-1.10/
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to 1.9.6:
  * Bump up Golang version and fix CVEs. (#5884, @blackpiglet)
  * Add labels for velero installed namespace to support PSA.
    (#5887, @blackpiglet)
  * Fix Dockerfile issue. (#5761, @blackpiglet)
  * Add PR container build action, which will not push image. Add
    GOARM parameter. (#5777, @blackpiglet)
  * Correct PVB/PVR Failed Phase patching during startup (#5829,
    @kaovilai)
- Update to version 1.9.5:
  * Add GOARM for restic compile failure
  * Add changelogs for v1.9.5
  * Add Restic builder in Dockerfile.
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.9.4:
  * Rollback compile restic
  * Fix CVE for trivy scan
  * remove old versions from kind CI (#5627)
  * Restore ClusterBootstrap before Cluster
* Thu Sep  7 2023 kastl@b1-systems.de
- Update to version 1.9.3:
  * Fix restic cross platform compile
  * Add compile restic binary for CVE fix
  * Fix controller problematic log output
  * Bump up golang version to 1.18.8
  * Generate v1.9.3 changelog (#5538)
  * Enhance the restore priorities list to support specifying the
    low prioritized resources that need to be restored in the last
  * Fix v1.9.3 CSI VolumeSnapshot status duplicate issue.
  * Bump up the distroless image to the latest version (#5500)
  * Cherry pick 5388 to v1.9.3 (#5482)
  * Fix CVE-2022-27191
  * Change the name of changelog file and update code/doc to pass
    checking
  * update k8s.io dependencies to 0.24.0
  - This also required an update to use github.com/bombsimon/logrusr/v3
  * 'WithClusterName' removed as per the k8s doc reasoning:
  - https://github.com/kubernetes/apimachinery/blob/release-1.24/pkg/apis/meta/v1/types.go\#L257-L259
  - ('ClusterName was a legacy field that was always cleared by
    the system and never used')
  - Test was updated accordingly
  * Exclude "csinodes.storage.k8s.io" and
    "volumeattachments.storage.k8s.io" from backup and restore by
    default.
  * Skip the exclusion check for additional resources returned by
    BIA
  * Amend changelog for v1.9.2
  * Generate changelog for v1.9.2
  * increase restic ensure repo timeout
  * Fix CVE-2022-1962 by bumping up golang verison to 1.17.13
    (#5286)
  * Add support to download CSI json from object store
  * fix edge cases for already exists resources
  * check vsc null pointer
  * Check for empty ns list before checking nslist[0]
  * Don't panic when storageClassName is not set in stateful sets
  * Fix code spell check fail
* Tue Nov  8 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.9.2:
  * Add annotation "pv.kubernetes.io/migrated-to" for CSI checking.
  * Fix CVE-2022-1962 by bumping up golang version to 1.17.13
  * Improvement to the CSI plugin in plugin v0.3.0
  * Skip registering "crd-remap-version" plugin when feature flag "EnableAPIGroupVersions" is set
  * Refactored the controllers using Kubebuilder v3
  * Optionally restore status on selected resources
    The restoreStatus option has been added to the CLI and Restore spec to enable
    you to control the group of resources whose status will be restored.
  * ExistingResourcePolicy in the restore API
  * Upgrade integrated Restic version and add skip TLS validation in Restic command
- Update to version 1.9.1:
  * Bump up base image and package version to fix CVEs
  * Amend changelogs for v1.9.1
  * Make CSI snapshot creation timeout configurable for backup and schedule.
  * Add annotation "pv.kubernetes.io/migrated-to" for CSI checking.
  * Generate the changelog for v1.9.1 (#5176)
  * Generate the changelog for v1.9.1
  * Fix restic backups to multiple backup storage locations bug
  * Skip registering "crd-remap-version" plugin when feature flag (#5165) (#5173)
  * Delay CA file deletion in PVB controller
  * Modify BackupStoreGetter to avoid BSL spec changes
  * Fix bsl validation bug
- Update to version 1.9.0:
  * Add changelog for rc2
  * When spec.RestoreStatus is empty, don't restore status
  * Fix tag release error
  * Bumpup plugin version for Velero 1.9 E2E test
  * Fix wrong bucket issue in BSL deletion E2E test
  * Pin the base image and golang image for v1.9.0 release
  * Add more explanation for gen-docs parameters
  * Amend doc 1.9 version
  * Add Changelog and Docs for v1.9
  * Enhance checkpoint of bsl deletion
  * Add more information for failing to get path or snapshot in
    restic backup and restore.
  * Update release instruction
  * Bugs fixing: use patch to update status and set default GC
    period
  * Undo setting the VSC's deletion policy during backup
  * Fix ordered resources cmd Stdout already set error
  * Disable status as sub resource in CRDs
  * Fix E2E test [Backups][Deletion][Restic] on GCP.
  * Mark in-progress CRs as failed when starting the server
  * Fix nightly running failure
  * Add more details about restore workflow (#4928)
  * add site bio/img for maintainer/contributor shubham-pampattiwar
  * Update the doc of CSI support
  * Bump up kind version to support Kubernetes 1.24
  * Add changelog
  * Add docs
  * Add details about using multiple volume snapshot locations and
    restic
  * Cleanup resetStatus
  * fix flag typo
  * Remove break line
  * Propose Shubham Pampattiwar as a maintainer
  * Include moer details
  * Update docs for flag to skip TLS validation
  * Make updates from review
  * Adds informaiton about resticRepoPrefix
  * Fix typos
  * Add schedule ordered resources test
  * Refactor to simplify
  * Enhance the map flag to support parsing input value contains
    entry delimiters
  * Make velero completion zsh command output can be used by
    `source` command.
  * Update cluster migration scenario with more details
  * Add resource limits testing information
  * Update wording and add more useful links
  * Remove jenting from maintainers (#4888)
  * Add note about restoring when resource scaled to 0
  * Add setting TTL in backup E2E test
  * Add restore status to cli
  * Update CRDs
  * Update codegen
  * Fixes tests hopefully
  * Add restore status mechanism
  * Add resource status
  * Add StatusUpdater
  * Fix DeepEqual when status is updated
  * add multiple label selector support to backup API
  * Refactor BSL controller with periodical enqueue source.
  * Make garbage collection for expired backups configurable
  * Update compatibility matrix for 1.9
  * fix typo
  * Add supported versions statment to support process page
  * add existingResourcePolicy to Restore API
  * Add Orlin and Abigail in the team on the site
  * Bump up the version of distroless to base-debian11
  * changes according to review comments
  * change func name and repository description
  * Make in-progress PVB/PVR as failed when restic controller
    restarts to avoid hanging backup/restore
  * Add snapshot checkpoint for CSI E2E test and fix CSI snapshot
    name issue
  * Add wording for using commands in hooks
  * continue rather than return for non-matching restore action
    label
  * Remove VolumeSnapshot created during backup, when the
    VolumeSnapshotClass's DeletionPolicy is set to Delete.
  * Make waiting VolumeSnapshot to ready process parallel.
  * Delete orphan CSI snapshots in backup sync controller
  * Add info about enviroment variables in pre/post hooks
  * Update resource filtering page
  * Update headers in supported providers page
  * Add aws limitation for migration, add limitation section
  * Refactor restic repository
  * cleanup restic helper folder when done
  * Update ROADMAP.md with link to wiki and wiki guidance
  * Bump up the version of library go-plugin
  * Change the name of UT to be more consistent
  * Add multiple label selector support to Velero backup /restore
    API
  * design for enabling existing resource policy
  * Refactor backup deletion controller based on kubebuilder
  * Add ClusterClasses to the restore priority list
  * Convert Pod Volume Restore resource/controller to the
    Kubebuilder framework
  * Make in-progress backup/restore as failed when doing the
    reconcile
  * Document steps to update helm chart for each Velero GA release
  * Remove DeletedBackupRequest information
  * Modify CSI VolumeSnapshot metric related code.
  * Add docs for deleting backups
  * Make the vsc created by backup sync controller deletable
  * Return the error when running reconcile to trigger the handling
    logic again
  * Update site/content/docs/main/api-types/restore.md
  * Update integrated Restic version and add insecureSkipTLSVerify
    for Restic CLI
  * Use controller-gen to generate the deep copy methods for
    objects
  * Update according to comments. Remove
    csiVolumeSnapshotsStorageTotal related code.
  * Fix default-backup-ttl not work
  * fix: delete empty backups
  * fix: use the right kind in getRestartableProcess logger
  * Update CRD and GRPC.
  * Add CSI VolumeSnapshot related metrics.
  * Avoid duplicated snapshotting, when CSI is enabled
  * Refactor schedule controller with kubebuilder
  * Add debug switcher for E2E test
  * Rename binary generated by go install cmd/*
  * Support CSI plugin in E2E test
  * Bump up to v1 API for CSI snapshot
  * Fix bug when pushing the build-image
  * Skip podvolumerestore creation when restore excludes pv/pvc
  * Add CSI plugin in E2E test
  * Support multi-upgrade-path in upgrade E2E test
  * Ensure the restore hook applied to new namespace based on the
    mapping
  * Add parameter for e2e test to support modify kibishii install
    path.
  * add bsl and vsl parameter links
  * Add labels to expired backups failing garbage collection.
    (#4757)
  * Update community managers in MAINTAINERS.md
  * metrics: add items gauges
  * Fix the golang lint error: Variable 'session' collides with
    imported package name
  * Correct copyright comment and string compare
  * Remove blocking indexing of our versioned docs (#4750)
  * Insert all restore errors and warnings into restore log (#4743)
  * Plugin versioning design (#4698)
  * clarify date/time (#4745)
  * Remove Bridget from maintainer list
  * Fix format.
  * Add unit tests, change copyright years and revert unrelated
    changes.
  * Add changelog
  * Adding PriorityClass to backup podAction and restore podAction.
  * Support multiple skip option for E2E test
  * Fixed start contributing link (#4723)
  * Add E2E test of bsl deletion
  * Clarify backups that get deleted via object storage sync
  * Support multiple skip option for E2E test
  * Fixed start contributing link (#4723)
  * Update BSL CR as long as there is any error
  * fix broken links in ibm config page (#4715)
  * Remove gcp auth action. Use JSON key as docker login secret
    instead.
  * Change authentication method from workload identity provider to
    service account key.
  * Add e2e for verify snapshto in VSL
  * Modify according to comments.
  * Enable coverage in test.sh and upload to codecov
  * Fix typo on tests fields name and add another test with gesture
    of errors wanted on equals
  * Fix labels removed in ObjectMeta
  * Add support for --pod-labels (#4694)
  * Add skip case support in e2e test
  * Bypass the remap CRD version plugin when v1beta1 CRD is not
    supported
  * Modify according to comments
  * Update --use-owner-references-in-backup description in velero
    command line
  * [fix] Add regional PV support for GKE
  * Append "-dev" suffix for the image tag of release branches
  * Enable building and pushing image for release branches
  * Don't exit when getting no match for grep
  * Remove the office hours from the community page
  * Add backup deletion e2e test
  * [fix] Avoid overwritten hook's exec.container parameter when
    running pod command executor
  * Add CloudCasa to "Adopters of Velero" section on velero.io
    (#4588)
  * Add Xun Jiang's profile information into Velero Website.
    (#4620)
  * Updates to 1.8 changelog
  * Copy edits for 1.8 release notes
  * Update release note to reflect the fix for #1980
  * Add more exempt labels for stalebot (#4641)
  * restic backupper: ignore volumes of non-running pods (#4584)
  * Add delete BSL cleanup highlight and fixed grammar in heading
  * Refine the release note of v1.8
  * Update e2e test image to gcr.io
  * Fix E2E backup namespaces test
  * Add Ming Qiu's profile information into Velero Website's
    contributor list
  * Add GCR login actions
  * Simplify by assuming nil is false and use boolptr util function
  * Add pushing image to GCR in github workflow
  * Make sure the tag-release script fail on any error
  * Add changelog for PR 4436
  * Minor change to trigger GitHub actions
  * Check for nil before logging DefaultVolumestToRestic value
  * Undeprecate the volumesnapshot plugin in the doc
  * Change 1.8 plugins version to release version
  * Fix E2E gcp plugin tag name
  * Add 1.8 plugins map in e2e test
  * Use OrderedResources in schedules (#4550)
  * Run go mod tidy
  * Replace r.Client.Update with patch helper
  * Remove Bridget McErlean from maintainers
  * E2E SSR test add retry mechanism and logs
  * Run go mod tidy
  * Convert PodVolumeBackup to Kubebuilder framework
  * Add timeout for CI e2e job
  * Nominate Xun Jiang and Ming Qiu to become maintainers (#4578)
  * Change dsu-igeek affiliation to Kasten, requires governance
    vote
  * Add continue-on-error in ci e2e test
  * Remove reference of restic_restore_action.go from the doc
  * Upload debug tarball in PR CI E2E pipeline
  * #4067 Initial design of the new plugins - pre-post backup and
    restore (#4083)
  * Add E2E test of backups sync from BSL
  * Fix: skip not mounted volumes when backing up
  * Clarify restore hook includedResources when not specified
    Signed-off-by: Tiger Kaovilai <tkaovila@redhat.com>
  * Fix bug to make the restic prune frequency configurable
  * update migration across different Kubernetes versions section
  * Fix lint issue and test failed
  * update dependancies
  * add changelog
  * Add doc for new secCtx cm key and missing
    secCtxAllowPrivilegeEscalation.
  * Add full support for setting securityContext for restic restore
    container
  Breaking changes
  With bumping up the API to v1 in CSI plugin, the v0.3.0 CSI plugin will only work for Kubernetes v1.20+.
  Upgrading:
  https://velero.io/docs/v1.9/upgrade-to-1.9/
* Thu Mar 17 2022 jenting.hsiao@suse.com
- Update to version 1.8.1:
  * Bump up golang to 1.17.8
  * Generate the changelog for v1.8.1
  * Bypass the remap CRD version plugin when v1beta1 CRD is not supported (#4706)
  * Append "-dev" suffix for the image tag of release branches
  * Enable building and pushing image for release branches
  * Modify according to comments
  * [fix] Add regional PV support for GKE
  * Check for nil before logging DefaultVolumesToRestic value
* Wed Feb 16 2022 jenting.hsiao@suse.com
- Update to version 1.8.0:
  * Undeprecate the volumesnapshot plugin in the doc
  * Clean up the change log
  * cherry pick to 1.8 Change 1.8 plugins version to release version
  * Cherry pick to1.8 - Add 1.8 plugins map in e2e test
  * E2E SSR test add retry mechanism and logs
  * Remove reference of restic_restore_action.go from the doc
  * Pin the base image and golang img for v1.8.0 release
  * Update changelog for v1.8.0 (#4530)
  * Update doc for v1.8
  * E2E test on ssr object with controller namespace mix-ups
  * Check whether the volume is provisioned by CSI driver or not by the annotation as well
  * Support running e2e testing on k8s 1.23.0
  * Check the existence of the expected service when ignoring the NodePort already allocated error
  * Fix E2E upgrade parameter issue caused by previous PR
  * Bump up velero version in upgrade test
  * add links to plugin repos
  * minor typo fixes
  * readme changes
  * Add kubernetes version compatability matrix
  * Initialize the labels field of `velero backup-location create` option
  * Update CSI docs with more context
  * Fix e2e 2500 namespaces scale test timeout problem
  * Add backup deletion e2e test
  * Parse resource from backup tarball directly rather than resolving it via discovery service to avoid #4009 (#4398)
  * Keep the annotation "pv.kubernetes.io/provisioned-by" when restoring PVs
  * Ignore the provided port is already allocated error when restoring the LoadBalancer service (#4462)
  * Return the error when getting backup store in backup deletion controller (#4465)
  * Add changelog.
  * Revert "Migrate backup sync controller from code-generator to kubebuilder (#4423)"
  * Update code standards to direct folks to create changelogs on release… (#4443)
  * Add rbac and annotation test cases
  * Fix statefulsets volumeClaimTemplates storageClassName after use Changing PV/PVC Storage Classes (#4375)
  * Upgrade e2e test vsphere plugin
  * Migrate backup sync controller from code-generator to kubebuilder (#4423)
  * Remove backups and restic repos associated with deleted BSL(s) (#4377)
  * Adds <backup-name>-itemsnapshots.gz file to backup (when provided). (#4429)
  * fix: remove --crds-version in velero install command
  * Consolidated code for resolving actions and plugins into ActionResolver (#4410)
  * Add defaultVolumesToRestic to schedule api docs
  * Fix e2e test failures for the inappropriate optimaze of velero install
  * Limit backup namespaces on test resource filtering cases
  * Added UploadProgressFeature flag to enable UploadProgressMonitoring and ItemSnapshotters
  * feat: improve documentation for reverse selector
  * Bump up Go to 1.17
  * Add resoure filtering test cases
  * Added ItemSnapshotter to the plugin server framework. (#4417)
  * update documentation (#4378)
  * Add restoreactionitem plugin to handle admission webhook configurations
  * Build for darwin_arm64 (#4409)
  * feat: migrate kubebuilder from v2 to v3
  * Update issue template to reference velero debug (#4384)
  * Adjust structure of e2e test codes Put every test moduels into seperate packages and all velero install parameters integrated into one struct
  * Add the key for GKE zone for AZ collection
  * Fix snapshot e2e test issue of jsonpath
  * fix: modify generated from schedule's backup name timestamp to UTC ti… (#4353)
  * Use logrusr instead of zap.
  * ItemSnapshotter plugin APIs.  Addresses #3753 (#4077)
  * Design doc for delete associated backup and restic repos when BSL is deleted (#4297)
  * Fix: add init log option for velero controller-runtime manager.
  * Fix: add init log option for velero controller-runtime manager.
  * Read Availability zone from nodeAffinity requirements
  * Use factory.Namespace() to replace hardcoded velero namespace (#4346)
  * Ignore the `provided port is already allocated` error when restoring the `NodePort` service (#4336)
  * Return the error if velero failed to detect S3 region for restic repo (#4343)
  * Fix: add init log option for velero controller-runtime manager.
  * PV remapClaimRefNS was being skipped when there was no snapshot (#3708)
  * Check the failed phases either when uploading the snapshot in E2E testing (#4162)
  * Only set BSL credential field if provided (#4322)
  * add 4306 changelog
  * - fix buggy pager func fix paging items in to use list options passed by the paging function
  * Verify group before treating resource as cohabitating (#4126)
  * Fix CVE-2020-29652 and CVE-2020-26160 (#4274)
  * Correct the environment variable for azure credential file (#4313)
  * Validation allows empty string namespace
  * Don't create a backup immediately after creating a schedule (#4281)
  * Add daniel to contributor list
  * Update the design of `velero debug` (#4081)
  * Add WenkaiYin to contributor list (#4277)
  * Limit  kubebuilder controllers to work only for objects in own namespaces
  * Namespace validation now allows asterisks
  * Update release instruction
  * Update 1.8 roadmap for Technical health
  * 1.8 roadmap (#4210)
  * Updated Tiltfile to pass REGISTRY env variable to build.sh Set default registry to be docker.io/velero in Tiltfile and example
  * Bump latest doc to v1.7
  * Initial draft of an object graph manifest (#3466)
  * #4040 - documentation - adding more troubleshooting information durin… (#4041)
  * Specify the "--snapshot-volumes=false" option explicitly when running backup with Restic
  * Refine tag-release.sh
* Thu Jan 27 2022 Robert Munteanu <rombert@apache.org>
- Added completion packages
* Fri Dec 10 2021 jenting.hsiao@suse.com
- Update to version 1.7.1:
  * Add change log for 1.7.1
  * add 4358 changelog
  * - fix buggy pager func fix paging items in to use list options passed by the paging function
  * Fix CVE-2020-29652 and CVE-2020-26160 (#4315)
  * Namespace validation now allows asterisks and empty string (#4316)
  * Comment in Dockerfile to explain the digest of base image (#4224)
* Thu Sep 30 2021 jenting.hsiao@suse.com
- Update to version 1.7.0:
  * Specify the "--snapshot-volumes=false" option explicitly when running backup with Restic
  * Pin the base image for v1.7 (#4180)
  * Fix plugins incompatible issue in upgrade test (#4141)
  * run backup/restore describe in debug subcommand (#4161)
  * Recovery the workround for aws pending issue
  * Use velero debug command to dump the logs when case failed
  * Fix the link and content for upgrade instruction
  * Add upgrade instructions for v1.7.0
  * Add upgrade test into E2E tests
  * Generate v1.7 docs
  * Generate 1.7 changelog
  * Add `velero debug` to documentation
  * Validate namespace in velero backup create command (#4057)
  * Empty the "ClusterIPs" along with "ClusterIP" when "ClusterIP" isn't "None" (#4101)
  * pass velero cli executable to crashd
  * Skip restic backup/restore of DownwardAPI volumes (#4076)
  * remove IsUnstructuredCRDReady (#4085)
  * Several fixes to improve the stability of E2E testing (#4056)
  * Enhance e2e test
  * Implement `velero debug` (#4022)
  * Install/uninstall velero by CLI in the E2E test case
  * Fix log print error using a wrong var name (#4063)
  * add changelog
  * fixes for CVE-2021-3121 and CVE-2021-3580
  * new roadmap for 1.7 (#4048)
  * Change the base image to distroless (#4055)
  * internal/delete: fix dropped error (#4016)
  * Add documentation for TLS error 116 (#3811)
  * Page list requests by default (#3823)
  * Wait the namespace deletion completed before removing the CRDs (#4007)
  * Update ibm-config.md (#4024)
  * Changed format of download request name to use a random UUID rather than (#4034)
  * Fix the random failure of E2E test cases (#4005)
  * Use LabelSelector in Action ResourceSelector
  * Skip restore of APIServices managed by Kubernetes
  * Distinguish between different unnamed node ports when preserving
  * Add Kubernetes v1.22 CI test
  * Use appropriate CRD API during readiness check (#4015)
  * Restic Backup: Add check if Pod is successful or failed for emptyDir.… (#3993)
  * pkg/install: fix dropped error
  * Bump up Go to 1.16 (#3990)
  * Select the velero deployment with both label and container name (#3996)
  * Updated uninstall to remove both v1beta1 and v1 CRDs if present (#3997)
  * Patch the resources of velero and kibishii when running E2E testing
  * Adding new meeting details to community documentation page (#4001)
  * enable e2e tests to choose crd apiVersion
  * Control the name of backup used in E2E test to avoid issue on vSphere (#3985)
  * Change CRDs default API version v1
  * Update the Tiltfile to use v1 CRDs
  * Update site documentation
  * Add CI CRD check on K8s v1.21.1
  * Update CI codespell check
  * Add changelog
  * Add new flag --crds-version of default CRD version to generated
  * Run script to generate both v1beta1 and v1 CRDs
  * Update script to generate both v1beta1 and v1 CRDs
  * Fixing multipleNamespaceTest bug - Missing expect statement in test (#3983)
  * Run "Basic" test cases only on Github Action for pull requests (#3989)
  * Bump up vSphere plugin version to v1.1.1
  * Generate test report for the E2E testing
  * Update stale bot setting (#3979)
  * Update upgrade instructions to reference v1.6.2 (#3977)
  * Add the design for `velero debug` (#3973)
  * Fix push-build-image target
  * Change restic image log messages to info level
  * Adding Replicated logo to adopters page - take 2
  * Update k8s libraries to latest patch version (#3953)
  * pkg/restore: fix dropped error
  * Allow registry to be configured at build time
  * Nominate Wenkai Yin to become a maintainer
  * Nominate Daniel Jiang to become a maintainer
  * Enable stale bot
  * Add changelog
  * Upgrade Velero ClusterRoleBinding to use v1 API
  * Fix -install-velero flag for e2e tests
  * Enable the E2E test on Github Action
  * So Long, and Thanks for All the Fish
  * Update upgrade instructions to reference v1.6.1 (#3893)
  * Fix:rss link blindly appends /blog/index.html (#3886)
  * Fix the link of release information (#3883)
  * regression introduced in 1.6 restore progress: fix CR restore (#3845)
  * Added multiple namespace test (#3763)
  * Add Labels field to BackupSpec (#3641)
  * Skip volume restores from projected sources (#3877)
  * API groups e2e tests remove controllers (#3564)
  * fix typos for code spell test
  * skip backuping projected volume
  * Update changelog for new PR.
  * Refactor GetRepoIdentifier tests and add new case
  * Consolidate api clients for e2e tests (#3764)
  * Remove ashish-amarnath as maintainer (#3842)
  * Delete residual file caused by network interruption and so on. Fixes #3204 (#3241)
  * Updated design to take into account protocol buffer limitations. (#3464)
  * Add document describing manual test cases (#3601)
  * Update Enable API Group Versions Feature docs (#3809)
  * Update MinIO docs for correct AWS plugin version (#3814)
  * Added BackupPhaseUploading and BackupPhaseUploadingPartialFailure backup (#3805)
  * Remove Nolan Brubaker from active contributors
  * Remove the [insert current year] in the code standards doc
  * Add information about compression in Velero (#3818)
  * Add PVC UID label to PVR (as we already have for PVB) (#3792)
  * Remove nrb from PR review rotation (#3810)
  * Support pulling plugins by digest (#3803)
  * Update docs to state Kubernetes v1.12 is needed (#3787)
  * Update docs to include schedule backup example (#3478)
  * Add note about updating CRDs during development (#3784)
  * service_action: use unstructured to marshal selective fields  (#3789)
  * Fix gh action (#3743)
  * Changed kibishii wait commands to output stdout/stderr, makes for better debugging (#3762)
  * ✨ ⚠️ Remove CSI volumesnapshot artifact deletion (#3734)
  * Added site bio/img for maintainer/contributor sseago (#3750)
  * Storage Supported Providers hyperlink is updated to refer to the correct path (#3667)
  * Design doc for upload progress monitoring (#3416)
  * Changes to secrets design (#3413)
  * Propose Scott Seago as a maintainer (#3747)
  * A small refactor of the e2e tests (#3726)
  * update other versions
  * fix on-premise `--plugins` flag documentation
  * Shorten OpenStack plugin documentation link text
  * Add cpanato as Emeritus Maintainers (#3725)
  * Fix typo in the restic document (#3728)
  * Fix typo in restic documentation
  * 🐛  Fix plugin name derivation from image name (#3711)
  * Fix misspelled file name (#3712)
  * Docs: include OpenStack plugin for version 1.6
  * Define a Velero release schedule (#3551)
  * Added release criteria to release-instructions (#3598)
  * Improve plugin release instructions (#3591)
  * Fix format
  * Fix path
  * Consolidate config files and fix path
  * Add Abbie to PR review requests
  * Add logo assets
  * Fix incorrect links in BSL docs (#3680)
  * Added Eleanor to Team Bios and to Maintainers page, removed Tim (#3593)
  * Add blog post for Velero 1.6 (#3676)
  * use region input to detect the Bucket region Signed-off-by: Jalaja Ganapathy <jalaja@replicated.com>
  * Docs: Add OpenStack list item to plugin page
  * Docs: include OpenStack plugin in community supported providers
  * Correctly render links with fragments on docs pages
* Fri Aug 13 2021 jenting.hsiao@suse.com
- Update to version 1.6.3:
  * Update changelog for v1.6.3
  * Merge pull request #4028 from zubron/add-restore-item-action-to-skip-automanaged-apiservices
  * Cherry-pick and update changelog for v1.6.3 (#4018)
  * Cherry pick changes for 1.6.3 and add changelog (#4006)
  * Fix bugs of E2E test cases
  * Support both v1beta1 and v1 CRDs for velero
  * Upgrade Velero ClusterRoleBinding to use v1 API (#3995)
* Wed Jul 21 2021 jenting.hsiao@suse.com
- Update to version 1.6.2:
  * Add changelog for v1.6.2
  * Merge pull request #3928 from zubron/customize-velero-image-at-build-time
  * Update k8s libraries to latest patch version (#3953)
* Thu Jun 24 2021 jenting.hsiao@suse.com
- Update to version 1.6.1:
  * Add changelog for v1.6.1
  * regression introduced in 1.6 restore progress: fix CR restore (#3845)
  * Skip volume restores from projected sources (#3877)
  * API groups e2e tests remove controllers (#3564)
  * Merge pull request #3866 from alaypatel07/fix-projected-volume-for-restic
  * Consolidate api clients for e2e tests (#3764)
  * A small refactor of the e2e tests (#3726)
  * 🐛  Fix plugin name derivation from image name (#3711)
* Wed Apr 14 2021 jenting.hsiao@suse.com
- Update to version 1.6.0:
  * Add changelog and docs for v1.6.0
  * Upgrade docs for v1.6.0-rc2 (#3662)
  * Revert printer columns (#3652)
  * Add changelog and docs for v1.6.0-rc.1
  * Allow Dockerfiles to be configurable (#3634)
  * Remove unnecessary check
  * Adress Ashish's second review
  * Runs vSphere tests with snapshots (#3629)
  * Address Ashish's review
  * Addressed Bridget's review
  * Addressed Dave's review
  * Make uninstall more robust and informative
  * Added volume snapshot test for backup/restore. (#3592)
  * Improve GH Action PR assign + labeling (#3584)
  * Update upgrade docs (#3568)
  * Upgrade e2e tests to new plugin versions (v1.2)
  * Restore progress reporting bug fix (#3583)
  * Install plugins for additional BSL in E2E test (#3582)
  * Updated Azure plugin in e2e tests to 1.1.2 (latest) (#3585)
  * Upgrade restic from v0.9.6 to v0.12.0 (#3528)
  * Use Credential from BSL for restic commands  (#3489)
  * Partially revert adding credentials to VSL (#3561)
  * Address review comments
  * Add E2E test for multiple credentials
  * Prefer conditional waiting over magic sleep (#3527)
  * Proposed 1.7.0 roadmap (#3537)
  * Assign a smaller number of reviewers to PRs (#3543)
  * fix broken build (#3525)
  * Pass configured BSL credential to plugin via config (#3442)
  * Restore progress reporting (#3125)
  * Support cli uninstall (#3399)
  * Convert DownloadRequest resource/controller to kubebuilder  (#3004)
  * Update in-code documentation to show resources can be specified with group name (#3498)
  * (low priority) Add port fwding info to Tilt doc (#3424)
  * Combine CRD install verification into 1 job, and update k8s versions (#3448)
  * (low priority) Update to Thompson (#3502)
  * Install CA certificates in Tilt Docker image (#3496)
  * Update PR template to use checkbox task lists (#3492)
  * Use pod namespace from backup when matching PVBs (#3475)
  * added documentation for how velero handles encryption (#3463)
  * E2E tests now run in multiple clouds in addition to KIND (#3286)
  * fix typo in item_hook_handler (#3361)
  * Use controller-runtime client to get restic secrets (#3320)
  * Restore API group version by priority (#3133)
  * Document design doc template (#3443)
  * Really fix the Github pull request template (#3444)
  * Use label to select Velero deployment in plugin cmd (#3447)
  * Remove pull request processing from prow action (#3445)
  * Add changelog
  * Restore CAPI cluster objects in a better order
  * Use correct suffix for Labeler config file (#3441)
  * Pin version of labeler action
  * Better validation
  * Better help messages and validation check
  * Fix typo
  * Add changelog
  * Add credential field to the bsl
  * Enable Prow commands when opening or readying PRs
  * Correct PR template file name
  * Unify labels across GitHub Actions
  * Update version of prow-action (#3434)
  * Add colors to describe command (#3275)
  * Enable automatic labeling of PRs via Actions (#3431)
  * Close issues after 35 total days of inactivity. (#3427)
  * Download restic binary using curl (#3421)
  * feat: support set BackupStorageLocation(BSL) CA certificate (#3167)
  * Modify InitContainer checking function that potentially incurs error (#3198)
  * Instantiate the flag map on set
  * Replace NewObjectBackupStore with interface (#3329)
  * Download restic binary outside container (#3327)
  * Add changelog entry
  * Add snapshot-location set command
  * Add credential arg to snapshot-location create
  * Add credential field to VolumeSnapshotLocation
  * Proposal for handling multiple credential secrets (#2403)
  * remove FAQ pages
  * Added information about minimum space required for Minio install. (#3393)
  * Update docs for running velero locally (#3363)
  * Remove references to zenhub (#3357)
  * Reword message for Q&A issue template
  * Fix typo (#3352)
  * fix(tests): make tests pass?
  * chore(gomod): bump k8s version
  * chore(update): run 'make update'
  * fix(tests): make tests pass
  * fix: apply patch
  * feat(gomod): bump versions
  * chore(changelog): add changelog message
  * refactor(external-snapshotter): bump to v4
  * refactor(gomod): move replaces
  * Add Q&A discussion to issue templates (#3339)
  * Support fish shell completion (#3231)
  * Update docs to clarify backup location and relationship with other data (#3309)
  * Add Tilt configuration to debug using Delve (#3189)
  * Updated for new repository for Kibishii Distributed Data Generator for e2e tests (#3267)
  * Raise logging level for PV deletion timeout (#3316)
  * Minor kubebuilder related items to clean up  (#3180)
  * Download Restic binary and copy into Tilt Velero image (#3310)
  * Increased limit for Velero pod to 512M.  Fixes #3234
  * Capitalize all help messages (#3209)
  * Nominate JenTing Hsiao for core maintainer (#3188)
  * Improve name formatting logic and add more tests
  * Fix path to crds.go file in codespell config (#3185)
  * Minor refactor plus better documentation for naming
  * issue: add flag to the schedule cmd to configure the `useOwnerReferencesInBackup` option  #3176 (#3182)
  * Better name format for init containers
  * Tencent S3 Compatible Support Docs (#3115)
  * Owner reference in backup when created from schedule (#3127)
  * Ignore config/crd/crds/crds.go file in codespell (#3174)
  * Use inline markdown links in tables (#3114)
  * ✨ Add more E2E tests and improvement (#3111)
  * Add changelog
  * Improvements to BSL logic
  * Revert workflow access token changes (#3170)
  * Preserve nodePort support with --preserve-nodeports flag (#3095)
  * Add milestoned issues to their respective board (#3162)
  * Use new repository-local board & github secret (#3163)
  * Change distro (#3166)
  * Draft design doc for restoring API group version by priority level (#3050)
  * feat: support configure BSL CR to indicate which one is the default (#3092)
  * Add Tilt configs (#3119)
  * 🐛 BSLs with validation disabled should be validated at least once (#3084)
  * Expand maintainer documentation (#3102)
  * Organize design docs (#3101)
  * Fix broken docker login action (#3121)
  * Upgrade to Docker provided buildx action for CI (#3110)
  * feat: add delete sub-command for backup-location (#3073)
  * Don't fail backup deletion if downloading tarball fails (#2993)
  * Add an E2E test framework to test Velero across cloud platforms (#3060)
  * 🏃‍♂️ reducing verbosity of another log message (#3109)
  * Modify function name typo (#3106)
  * Fix project automation (#3089)
  * 📖 Add docs to troubleshoot cloud-credentials (#3100)
  * pass annotations from scheduler to created backup (#3067)
  * Update to latest covenant coc (#3076)
  * propose restore progress (#3016)
  * Design doc for RestoreItemAction wait for AdditionalItems to be ready (#2867)
  * 🏃‍♂️ Turn down logging verbosity (#3091)
  * Add instructions to clone repo for examples (#3074)
  * 🏃‍♂️ update setup-kind github actions CI (#3085)
  * Add Dave Uchida (#3077)
  * 📖 use correct link to the minio.md (#3071)
  * Automate adding opened issues to the triage board (#3068)
  * 🐛 Do not run ItemAction plugins for unresolvable types for all types (#3059)
  * .github/workflows: add PR codespell workflow (#3064)
  * Fix various typos found by codespell (#3057)
  * 🐛 Use namespace and name to match PVB to Pod restore (#3051)
  * Add custom 404 page to website (#3056)
  * fixing 'velero.io/change-pvc-node-selector' plugin to fetch configmap using plugin name (#2970)
  * 🏃‍♂ Improve log message clarity (#3047)
  * 📖 Clarify restore hook init container priority (#3030)
  * Add additional printer columns for CRDs (#2881)
  * 📖 fix image links in how-velero-works page (#3031)
  * Add warning to velero version cmd. Fixes #3017 (#3024)
  * fix of microsoft typo in restic docs (#3037)
  * fix minio code samples (#3034)
  * Adding fix for restic init container index on restores. (#3011)
  * Ensure PVs and PVCs remain bound when doing a restore (#3007)
  * Add initial instructions for releasing plugins (#2952)
  * create CRB with velero-<namespace> (#2886)
  * Auto assign reviewers when PR is ready for review (#3006)
  * Check existing remote branches in release script (#2951)
  * Include --validate=false in upgrade instructions (#2969)
  * 📖 document restic limitation of backing only pod volumes (#2976)
  * Bump Go to 1.15 (#2974)
  * Fix BSL controller to avoid invoking init() on all BSLs regardless of ValidationFrequency (#2992)
  * Fix version cmd getting nil pointer (#2996)
  * Centralize + rename controller names and list (#2936)
  * Allow Timezone change in the container (#2944)
  * Update ROADMAP.md (#2986)
  * restore proper lowercase/plural CRD resource (#2949)
  * Stephanie Bauman is leaving the velero project (#2985)
  * Allow remote for release process to be configured (#2950)
  * Improve release docs following v1.5.1 release (#2954)
  * Fix adopters logos (#2968)
  * Don't attempt to publish docker images on forks (#2953)
  * Add Velero Office Hours info (#2962)
  * Fix 'subcommand required' error w/ cobra upgrade (#2947)
  * v1.5 blog post (#2940)
* Thu Apr  8 2021 jenting.hsiao@suse.com
- Update to version 1.5.4:
  * Add cherry-pick commits and changelog for v1.5.4 (#3651)
* Sat Jan 16 2021 jenting.hsiao@suse.com
- Update to version 1.5.3:
  * Add changelog for v1.5.3
  * Increased limit for Velero pod to 512M.  Fixes #3234
  * 🐛 BSLs with validation disabled should be validated at least once (#3084)
  * Don't fail backup deletion if downloading tarball fails (#2993)
  * 🐛 Do not run ItemAction plugins for unresolvable types for all types (#3059)
  * 🐛 Use namespace and name to match PVB to Pod restore (#3051)
  * Adding fix for restic init container index on restores. (#3011)
  * v1.5.2 changelogs and cherry-picks (#3023)
  * Add changelog and docs for v1.5 release (#2941)
  * Spruce up release instructions and release scripts (#2931)
* Tue Nov 10 2020 jenting hsiao <jenting.hsiao@suse.com>
- Update to version v1.5.2
  - Fix BSL controller to avoid invoking init() on all BSLs regardless of ValidationFrequency (#2992, @betta1)
  - cli: allow creating multiple instances of Velero across two different namespaces (#2886, @alaypatel07)
  - Restore CRD Resource name to fix CRD wait functionality. (#2949, @sseago)
  - Ensure that bound PVCs and PVs remain bound on restore. (#3007, @nrb). This fixes CVE-2020-3996.
* Wed Oct 14 2020 Jan Engelhardt <jengelh@inai.de>
- Avoid double %%setup calls.
* Tue Oct 13 2020 jenting hsiao <jenting.hsiao@suse.com>
- Update to version v1.5.1
  - Auto Volume Backup Using Restic with --default-volumes-to-restic flag
  - DeleteItemAction plugins
  - Code modernization
  - Restore Hooks: InitContianer Restore Hooks and Exec Restore Hooks
* Fri Jul 31 2020 jenting hsiao <jenting.hsiao@suse.com>
- Add patch: add a flag cacert for velero backup-location create
* Mon Jul 20 2020 jenting hsiao <jenting.hsiao@suse.com>
- Update to version v1.4.2
  - v1.4.2
  * log a warning instead of erroring if an additional item returned from a plugin can't be found in the Kubernetes API (#2595, @skriss)
  * Adjust restic default time out to 4 hours and base pod resource requests to 500m CPU/512Mi memory. (#2696, @nrb)
  * capture version of the CRD prior before invoking the remap_crd_version backup item action (#2683, @ashish-amarnath)
  - v1.4.0
  * increment restic volumesnapshot count after successful pvb create (#2542, @ashish-amarnath)
  * Add details of CSI volumesnapshotcontents associated with a backup to velero backup describe when the EnableCSI feature flag is given on the velero client. (#2448, @nrb)
  * Allow users the option to retrieve all versions of a given resource (instead of just the preferred version) from the API server with the EnableAPIGroupVersions feature flag. (#2373, @brito-rafa)
  * Changed backup tarball format to store all versions of a given resource, updated backup tarball format to 1.1.0. (#2373, @brito-rafa)
  * allow feature flags to be passed from install CLI (#2503, @ashish-amarnath)
  * sync backups' CSI API objects into the cluster as part of the backup sync controller (#2496, @ashish-amarnath)
  * bug fix: in error location logging hook, if the item logged under the error key doesn't implement the error interface, don't return an error since this is a valid scenario (#2487, @skriss)
  * bug fix: in CRD restore plugin, don't use runtime.DefaultUnstructuredConverter.FromUnstructured(...) to avoid conversion issues when float64 fields contain int values (#2484, @skriss)
  * during backup deletion also delete CSI volumesnapshotcontents that were created as a part of the backup but the associated volumesnapshot object does not exist (#2480, @ashish-amarnath)
  * If plugins don't support the --features flag, don't pass it to them. Also, update the standard plugin server to ignore unknown flags. (#2479, @skriss)
  * At backup time, if a CustomResourceDefinition appears to have been created via the v1beta1 endpoint, retrieve it from the v1beta1 endpoint instead of simply changing the APIVersion. (#2478, @nrb)
  * update container base images from ubuntu:bionic to ubuntu:focal (#2471, @skriss)
  * bug fix: when a resource includes/excludes list contains unresolvable items, don't remove them from the list, so that the list doesn't inadvertently end up matching all resources. (#2462, @skriss)
  * Azure: add support for getting storage account key for restic directly from an environment variable (#2455, @jaygridley)
  * Support to skip VSL validation for the backup having SnapshotVolumes set to false or created with --snapshot-volumes=false (#2450, @mynktl)
  * report backup progress (number of items backed up so far out of an estimated total number of items) during backup in the logs and as status fields on the Backup custom resource (#2440, @skriss)
  * bug fix: populate namespace in logs for backup errors (#2438, @skriss)
  * during backup deletion also delete CSI volumesnapshots that were created as a part of the backup (#2411, @ashish-amarnath)
  * bump Kubernetes module dependencies to v0.17.4 to get fix for kubernetes/kubernetes#86149 (#2407, @skriss)
  * bug fix: save PodVolumeBackup manifests to object storage even if the volume was empty, so that on restore, the PV is dynamically reprovisioned if applicable (#2390, @skriss)
  * Adding new restoreItemAction for PVC to update the selected-node annotation (#2377, @mynktl)
  * Added a --cacert flag to the install command to provide the CA bundle to use when verifying TLS connections to object storage (#2368, @mansam)
  * Added a --cacert flag to the velero client describe, download, and logs commands to allow passing a path to a certificate to use when verifying TLS connections to object storage. Also added a corresponding client config option called cacert which takes a path to a certificate bundle to use as a default when --cacert is not specified. (#2364, @mansam)
  * support setting a custom CA certificate on a BSL to use when verifying TLS connections (#2353, @mansam)
  * adding annotations on backup CRD for k8s major, minor and git versions (#2346, @brito-rafa)
  * When the EnableCSI feature flag is provided, upload CSI VolumeSnapshots and VolumeSnapshotContents to object storage as gzipped JSON. (#2323, @nrb)
  * add CSI snapshot API types into default restore priorities (#2318, @ashish-amarnath)
  * refactoring: wait for all informer caches to sync before running controllers (#2299, @skriss)
  * refactor restore code to lazily resolve resources via discovery and eliminate second restore loop for instances of restored CRDs (#2248, @skriss)
  * upgrade to go 1.14 and migrate from dep to go modules (#2214, @skriss)
  * clarify the wording for restore describe for namespaces included
  - v1.3.2
  * Allow plugins/ as a valid top-level directory within backup storage locations. This directory is a place for plugin authors to store arbitrary data as needed. It is recommended to create an additional subdirectory under plugins/ specifically for your plugin, e.g. plugins/my-plugin-data/. (#2350, @skriss)
  * bug fix: don't panic in velero restic repo get when last maintenance time is nil (#2315, @skriss)
* Tue Mar 24 2020 jenting hsiao <jenting.hsiao@suse.com>
- Pass git tree status = clean to fix `velero version` output Git commit with trailing dash
* Wed Mar 11 2020 Clark Hsu <clark.hsu@suse.com>
- Bump version 1.3.1
* Mon Mar  2 2020 jenting hsiao <jenting.hsiao@suse.com>
- Bump version 1.3.0
* Mon Feb 24 2020 jenting hsiao <jenting.hsiao@suse.com>
- Simplify rpm spec
* Fri Jan  3 2020 Klaus Kämpf <kkaempf@suse.com>
- fix velero-restic-restore-helper package name
* Fri Jan  3 2020 Klaus Kämpf <kkaempf@suse.com>
- Initial package v1.2.0
